import { Component, OnInit } from '@angular/core';
import { HttpResponse } from '@angular/common/http';
// eslint-disable-next-line @typescript-eslint/no-unused-vars
import { FormBuilder, Validators } from '@angular/forms';
import { ActivatedRoute } from '@angular/router';
import { Observable } from 'rxjs';

import { ISavedSearches, SavedSearches } from 'app/shared/model/saved-searches.model';
import { SavedSearchesService } from './saved-searches.service';
import { IUser } from 'app/admin/user-management/user-management.model';
import { UserManagementService } from 'app/admin/user-management/service/user-management.service';

@Component({
  selector: 'jhi-saved-searches-update',
  templateUrl: './saved-searches-update.component.html',
})
export class SavedSearchesUpdateComponent implements OnInit {
  isSaving = false;
  users: IUser[] = [];

  editForm = this.fb.group({
    id: [],
    name: [null, [Validators.required, Validators.minLength(1)]],
    jsonQuery: [null, [Validators.required]],
    userId: [null, Validators.required],
  });

  constructor(
    protected savedSearchesService: SavedSearchesService,
    protected userService: UserManagementService,
    protected activatedRoute: ActivatedRoute,
    private fb: FormBuilder
  ) {}

  ngOnInit(): void {
    this.activatedRoute.data.subscribe(({ savedSearches }) => {
      this.updateForm(savedSearches);

      this.userService.query().subscribe((res: HttpResponse<IUser[]>) => (this.users = res.body || []));
    });
  }

  updateForm(savedSearches: ISavedSearches): void {
    this.editForm.patchValue({
      id: savedSearches.id,
      name: savedSearches.name,
      jsonQuery: savedSearches.jsonQuery,
      userId: savedSearches.userId,
    });
  }

  previousState(): void {
    window.history.back();
  }

  save(): void {
    this.isSaving = true;
    const savedSearches = this.createFromForm();
    if (savedSearches.id !== undefined) {
      this.subscribeToSaveResponse(this.savedSearchesService.update(savedSearches));
    } else {
      this.subscribeToSaveResponse(this.savedSearchesService.create(savedSearches));
    }
  }

  private createFromForm(): ISavedSearches {
    return {
      ...new SavedSearches(),
      id: this.editForm.get(['id'])!.value,
      name: this.editForm.get(['name'])!.value,
      jsonQuery: this.editForm.get(['jsonQuery'])!.value,
      userId: this.editForm.get(['userId'])!.value,
    };
  }

  protected subscribeToSaveResponse(result: Observable<HttpResponse<ISavedSearches>>): void {
    result.subscribe(
      () => this.onSaveSuccess(),
      () => this.onSaveError()
    );
  }

  protected onSaveSuccess(): void {
    this.isSaving = false;
    this.previousState();
  }

  protected onSaveError(): void {
    this.isSaving = false;
  }

  trackById(index: number, item: IUser): any {
    return item.id;
  }
}
